
Disallow the use of old passwords
-------

**Description:**

This is a mitigation of the risk that a passsword can leak by any means. 
By changing the password to a new one minimizes the damage.


**Solution:**

Keep the old entries of the password record of the user. If the user changes his password 
you can match against the old entries to validate it&#39;s not an old one.
	